import * as pulumi from "@pulumi/pulumi";
/**
 * This resource allows you to create and manage an OpenID Connect subject claim customization template within a GitHub
 * organization.
 *
 * More information on integrating GitHub with cloud providers using OpenID Connect and a list of available claims is
 * available in the [Actions documentation](https://docs.github.com/en/actions/deployment/security-hardening-your-deployments/about-security-hardening-with-openid-connect).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const exampleTemplate = new github.ActionsOrganizationOidcSubjectClaimCustomizationTemplate("example_template", {includeClaimKeys: [
 *     "actor",
 *     "context",
 *     "repository_owner",
 * ]});
 * ```
 *
 * ## Import
 *
 * This resource can be imported using the organization's name.
 *
 * ```sh
 * $ pulumi import github:index/actionsOrganizationOidcSubjectClaimCustomizationTemplate:ActionsOrganizationOidcSubjectClaimCustomizationTemplate test example_organization
 * ```
 */
export declare class ActionsOrganizationOidcSubjectClaimCustomizationTemplate extends pulumi.CustomResource {
    /**
     * Get an existing ActionsOrganizationOidcSubjectClaimCustomizationTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ActionsOrganizationOidcSubjectClaimCustomizationTemplateState, opts?: pulumi.CustomResourceOptions): ActionsOrganizationOidcSubjectClaimCustomizationTemplate;
    /**
     * Returns true if the given object is an instance of ActionsOrganizationOidcSubjectClaimCustomizationTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ActionsOrganizationOidcSubjectClaimCustomizationTemplate;
    /**
     * A list of OpenID Connect claims.
     */
    readonly includeClaimKeys: pulumi.Output<string[]>;
    /**
     * Create a ActionsOrganizationOidcSubjectClaimCustomizationTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ActionsOrganizationOidcSubjectClaimCustomizationTemplate resources.
 */
export interface ActionsOrganizationOidcSubjectClaimCustomizationTemplateState {
    /**
     * A list of OpenID Connect claims.
     */
    includeClaimKeys?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a ActionsOrganizationOidcSubjectClaimCustomizationTemplate resource.
 */
export interface ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs {
    /**
     * A list of OpenID Connect claims.
     */
    includeClaimKeys: pulumi.Input<pulumi.Input<string>[]>;
}
