import * as pulumi from "@pulumi/pulumi";
/**
 * This resource allows you to set the access level of a non-public repositories actions and reusable workflows for use in other repositories.
 * You must have admin access to a repository to use this resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = new github.Repository("example", {
 *     name: "my-repository",
 *     visibility: "private",
 * });
 * const test = new github.ActionsRepositoryAccessLevel("test", {
 *     accessLevel: "user",
 *     repository: example.name,
 * });
 * ```
 *
 * ## Import
 *
 * This resource can be imported using the name of the GitHub repository:
 *
 * ```sh
 * $ pulumi import github:index/actionsRepositoryAccessLevel:ActionsRepositoryAccessLevel test my-repository
 * ```
 */
export declare class ActionsRepositoryAccessLevel extends pulumi.CustomResource {
    /**
     * Get an existing ActionsRepositoryAccessLevel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ActionsRepositoryAccessLevelState, opts?: pulumi.CustomResourceOptions): ActionsRepositoryAccessLevel;
    /**
     * Returns true if the given object is an instance of ActionsRepositoryAccessLevel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ActionsRepositoryAccessLevel;
    /**
     * Where the actions or reusable workflows of the repository may be used. Possible values are `none`, `user`, `organization`, or `enterprise`.
     */
    readonly accessLevel: pulumi.Output<string>;
    /**
     * The GitHub repository
     */
    readonly repository: pulumi.Output<string>;
    /**
     * Create a ActionsRepositoryAccessLevel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ActionsRepositoryAccessLevelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ActionsRepositoryAccessLevel resources.
 */
export interface ActionsRepositoryAccessLevelState {
    /**
     * Where the actions or reusable workflows of the repository may be used. Possible values are `none`, `user`, `organization`, or `enterprise`.
     */
    accessLevel?: pulumi.Input<string>;
    /**
     * The GitHub repository
     */
    repository?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ActionsRepositoryAccessLevel resource.
 */
export interface ActionsRepositoryAccessLevelArgs {
    /**
     * Where the actions or reusable workflows of the repository may be used. Possible values are `none`, `user`, `organization`, or `enterprise`.
     */
    accessLevel: pulumi.Input<string>;
    /**
     * The GitHub repository
     */
    repository: pulumi.Input<string>;
}
