import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ## Import
 *
 * This resource can be imported using an ID made up of the `repository` and `secret_name`:
 *
 * ```sh
 * $ pulumi import github:index/actionsSecret:ActionsSecret example_secret repository/secret_name
 * ```
 * NOTE: the implementation is limited in that it won't fetch the value of the
 * `plaintext_value` or `encrypted_value` fields when importing. You may need to ignore changes for these as a workaround.
 */
export declare class ActionsSecret extends pulumi.CustomResource {
    /**
     * Get an existing ActionsSecret resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ActionsSecretState, opts?: pulumi.CustomResourceOptions): ActionsSecret;
    /**
     * Returns true if the given object is an instance of ActionsSecret.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ActionsSecret;
    /**
     * Date of actionsSecret creation.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Encrypted value of the secret using the GitHub public key in Base64 format.
     */
    readonly encryptedValue: pulumi.Output<string | undefined>;
    /**
     * Plaintext value of the secret to be encrypted
     */
    readonly plaintextValue: pulumi.Output<string | undefined>;
    /**
     * Name of the repository
     */
    readonly repository: pulumi.Output<string>;
    /**
     * Name of the secret
     */
    readonly secretName: pulumi.Output<string>;
    /**
     * Date of actionsSecret update.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a ActionsSecret resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ActionsSecretArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ActionsSecret resources.
 */
export interface ActionsSecretState {
    /**
     * Date of actionsSecret creation.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * Encrypted value of the secret using the GitHub public key in Base64 format.
     */
    encryptedValue?: pulumi.Input<string>;
    /**
     * Plaintext value of the secret to be encrypted
     */
    plaintextValue?: pulumi.Input<string>;
    /**
     * Name of the repository
     */
    repository?: pulumi.Input<string>;
    /**
     * Name of the secret
     */
    secretName?: pulumi.Input<string>;
    /**
     * Date of actionsSecret update.
     */
    updatedAt?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ActionsSecret resource.
 */
export interface ActionsSecretArgs {
    /**
     * Encrypted value of the secret using the GitHub public key in Base64 format.
     */
    encryptedValue?: pulumi.Input<string>;
    /**
     * Plaintext value of the secret to be encrypted
     */
    plaintextValue?: pulumi.Input<string>;
    /**
     * Name of the repository
     */
    repository: pulumi.Input<string>;
    /**
     * Name of the secret
     */
    secretName: pulumi.Input<string>;
}
