import * as pulumi from "@pulumi/pulumi";
/**
 * This resource allows you to create and manage GitHub Actions variables within your GitHub repositories.
 * You must have write access to a repository to use this resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const exampleVariable = new github.ActionsVariable("example_variable", {
 *     repository: "example_repository",
 *     variableName: "example_variable_name",
 *     value: "example_variable_value",
 * });
 * ```
 *
 * ## Import
 *
 * GitHub Actions variables can be imported using an ID made up of `repository:variable_name`, e.g.
 *
 * ```sh
 * $ pulumi import github:index/actionsVariable:ActionsVariable myvariable myrepo:myvariable
 * ```
 */
export declare class ActionsVariable extends pulumi.CustomResource {
    /**
     * Get an existing ActionsVariable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ActionsVariableState, opts?: pulumi.CustomResourceOptions): ActionsVariable;
    /**
     * Returns true if the given object is an instance of ActionsVariable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ActionsVariable;
    /**
     * Date of actionsVariable creation.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * Name of the repository
     */
    readonly repository: pulumi.Output<string>;
    /**
     * Date of actionsVariable update.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Value of the variable
     */
    readonly value: pulumi.Output<string>;
    /**
     * Name of the variable
     */
    readonly variableName: pulumi.Output<string>;
    /**
     * Create a ActionsVariable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ActionsVariableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ActionsVariable resources.
 */
export interface ActionsVariableState {
    /**
     * Date of actionsVariable creation.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * Name of the repository
     */
    repository?: pulumi.Input<string>;
    /**
     * Date of actionsVariable update.
     */
    updatedAt?: pulumi.Input<string>;
    /**
     * Value of the variable
     */
    value?: pulumi.Input<string>;
    /**
     * Name of the variable
     */
    variableName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ActionsVariable resource.
 */
export interface ActionsVariableArgs {
    /**
     * Name of the repository
     */
    repository: pulumi.Input<string>;
    /**
     * Value of the variable
     */
    value: pulumi.Input<string>;
    /**
     * Name of the variable
     */
    variableName: pulumi.Input<string>;
}
