import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve the list of secrets of the repository environment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsEnvironmentSecrets({
 *     name: "exampleRepo",
 *     environment: "exampleEnvironment",
 * });
 * ```
 */
export declare function getActionsEnvironmentSecrets(args: GetActionsEnvironmentSecretsArgs, opts?: pulumi.InvokeOptions): Promise<GetActionsEnvironmentSecretsResult>;
/**
 * A collection of arguments for invoking getActionsEnvironmentSecrets.
 */
export interface GetActionsEnvironmentSecretsArgs {
    environment: string;
    fullName?: string;
    /**
     * Name of the secret
     */
    name?: string;
}
/**
 * A collection of values returned by getActionsEnvironmentSecrets.
 */
export interface GetActionsEnvironmentSecretsResult {
    readonly environment: string;
    readonly fullName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Name of the secret
     */
    readonly name: string;
    /**
     * list of secrets for the environment
     */
    readonly secrets: outputs.GetActionsEnvironmentSecretsSecret[];
}
/**
 * Use this data source to retrieve the list of secrets of the repository environment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsEnvironmentSecrets({
 *     name: "exampleRepo",
 *     environment: "exampleEnvironment",
 * });
 * ```
 */
export declare function getActionsEnvironmentSecretsOutput(args: GetActionsEnvironmentSecretsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetActionsEnvironmentSecretsResult>;
/**
 * A collection of arguments for invoking getActionsEnvironmentSecrets.
 */
export interface GetActionsEnvironmentSecretsOutputArgs {
    environment: pulumi.Input<string>;
    fullName?: pulumi.Input<string>;
    /**
     * Name of the secret
     */
    name?: pulumi.Input<string>;
}
