import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve the list of variables of the repository environment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsEnvironmentVariables({
 *     name: "exampleRepo",
 *     environment: "exampleEnvironment",
 * });
 * ```
 */
export declare function getActionsEnvironmentVariables(args: GetActionsEnvironmentVariablesArgs, opts?: pulumi.InvokeOptions): Promise<GetActionsEnvironmentVariablesResult>;
/**
 * A collection of arguments for invoking getActionsEnvironmentVariables.
 */
export interface GetActionsEnvironmentVariablesArgs {
    environment: string;
    fullName?: string;
    /**
     * Name of the variable
     */
    name?: string;
}
/**
 * A collection of values returned by getActionsEnvironmentVariables.
 */
export interface GetActionsEnvironmentVariablesResult {
    readonly environment: string;
    readonly fullName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Name of the variable
     */
    readonly name: string;
    /**
     * list of variables for the environment
     */
    readonly variables: outputs.GetActionsEnvironmentVariablesVariable[];
}
/**
 * Use this data source to retrieve the list of variables of the repository environment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsEnvironmentVariables({
 *     name: "exampleRepo",
 *     environment: "exampleEnvironment",
 * });
 * ```
 */
export declare function getActionsEnvironmentVariablesOutput(args: GetActionsEnvironmentVariablesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetActionsEnvironmentVariablesResult>;
/**
 * A collection of arguments for invoking getActionsEnvironmentVariables.
 */
export interface GetActionsEnvironmentVariablesOutputArgs {
    environment: pulumi.Input<string>;
    fullName?: pulumi.Input<string>;
    /**
     * Name of the variable
     */
    name?: pulumi.Input<string>;
}
