import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about a GitHub Actions public key. This data source is required to be used with other GitHub secrets interactions.
 * Note that the provider `token` must have admin rights to a repository to retrieve it's action public key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsPublicKey({
 *     repository: "example_repo",
 * });
 * ```
 */
export declare function getActionsPublicKey(args: GetActionsPublicKeyArgs, opts?: pulumi.InvokeOptions): Promise<GetActionsPublicKeyResult>;
/**
 * A collection of arguments for invoking getActionsPublicKey.
 */
export interface GetActionsPublicKeyArgs {
    /**
     * Name of the repository to get public key from.
     */
    repository: string;
}
/**
 * A collection of values returned by getActionsPublicKey.
 */
export interface GetActionsPublicKeyResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Actual key retrieved.
     */
    readonly key: string;
    /**
     * ID of the key that has been retrieved.
     */
    readonly keyId: string;
    readonly repository: string;
}
/**
 * Use this data source to retrieve information about a GitHub Actions public key. This data source is required to be used with other GitHub secrets interactions.
 * Note that the provider `token` must have admin rights to a repository to retrieve it's action public key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsPublicKey({
 *     repository: "example_repo",
 * });
 * ```
 */
export declare function getActionsPublicKeyOutput(args: GetActionsPublicKeyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetActionsPublicKeyResult>;
/**
 * A collection of arguments for invoking getActionsPublicKey.
 */
export interface GetActionsPublicKeyOutputArgs {
    /**
     * Name of the repository to get public key from.
     */
    repository: pulumi.Input<string>;
}
