import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve a GitHub Actions repository registration token. This token can then be used to register a self-hosted runner.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsRegistrationToken({
 *     repository: "example_repo",
 * });
 * ```
 */
export declare function getActionsRegistrationToken(args: GetActionsRegistrationTokenArgs, opts?: pulumi.InvokeOptions): Promise<GetActionsRegistrationTokenResult>;
/**
 * A collection of arguments for invoking getActionsRegistrationToken.
 */
export interface GetActionsRegistrationTokenArgs {
    /**
     * Name of the repository to get a GitHub Actions registration token for.
     */
    repository: string;
}
/**
 * A collection of values returned by getActionsRegistrationToken.
 */
export interface GetActionsRegistrationTokenResult {
    /**
     * The token expiration date.
     */
    readonly expiresAt: number;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly repository: string;
    /**
     * The token that has been retrieved.
     */
    readonly token: string;
}
/**
 * Use this data source to retrieve a GitHub Actions repository registration token. This token can then be used to register a self-hosted runner.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsRegistrationToken({
 *     repository: "example_repo",
 * });
 * ```
 */
export declare function getActionsRegistrationTokenOutput(args: GetActionsRegistrationTokenOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetActionsRegistrationTokenResult>;
/**
 * A collection of arguments for invoking getActionsRegistrationToken.
 */
export interface GetActionsRegistrationTokenOutputArgs {
    /**
     * Name of the repository to get a GitHub Actions registration token for.
     */
    repository: pulumi.Input<string>;
}
