import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve the list of secrets for a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsSecrets({
 *     name: "example",
 * });
 * ```
 */
export declare function getActionsSecrets(args?: GetActionsSecretsArgs, opts?: pulumi.InvokeOptions): Promise<GetActionsSecretsResult>;
/**
 * A collection of arguments for invoking getActionsSecrets.
 */
export interface GetActionsSecretsArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: string;
    /**
     * The name of the repository.
     */
    name?: string;
}
/**
 * A collection of values returned by getActionsSecrets.
 */
export interface GetActionsSecretsResult {
    readonly fullName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Secret name
     */
    readonly name: string;
    /**
     * list of secrets for the repository
     */
    readonly secrets: outputs.GetActionsSecretsSecret[];
}
/**
 * Use this data source to retrieve the list of secrets for a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getActionsSecrets({
 *     name: "example",
 * });
 * ```
 */
export declare function getActionsSecretsOutput(args?: GetActionsSecretsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetActionsSecretsResult>;
/**
 * A collection of arguments for invoking getActionsSecrets.
 */
export interface GetActionsSecretsOutputArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: pulumi.Input<string>;
    /**
     * The name of the repository.
     */
    name?: pulumi.Input<string>;
}
