import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about a repository branch.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const development = github.getBranch({
 *     repository: "example",
 *     branch: "development",
 * });
 * ```
 */
export declare function getBranch(args: GetBranchArgs, opts?: pulumi.InvokeOptions): Promise<GetBranchResult>;
/**
 * A collection of arguments for invoking getBranch.
 */
export interface GetBranchArgs {
    /**
     * The repository branch to retrieve.
     */
    branch: string;
    /**
     * The GitHub repository name.
     */
    repository: string;
}
/**
 * A collection of values returned by getBranch.
 */
export interface GetBranchResult {
    readonly branch: string;
    /**
     * An etag representing the Branch object.
     */
    readonly etag: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A string representing a branch reference, in the form of `refs/heads/<branch>`.
     */
    readonly ref: string;
    readonly repository: string;
    /**
     * A string storing the reference's `HEAD` commit's SHA1.
     */
    readonly sha: string;
}
/**
 * Use this data source to retrieve information about a repository branch.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const development = github.getBranch({
 *     repository: "example",
 *     branch: "development",
 * });
 * ```
 */
export declare function getBranchOutput(args: GetBranchOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetBranchResult>;
/**
 * A collection of arguments for invoking getBranch.
 */
export interface GetBranchOutputArgs {
    /**
     * The repository branch to retrieve.
     */
    branch: pulumi.Input<string>;
    /**
     * The GitHub repository name.
     */
    repository: pulumi.Input<string>;
}
