import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve the list of codespaces secrets for a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getCodespacesSecrets({
 *     name: "example_repository",
 * });
 * const example2 = github.getCodespacesSecrets({
 *     fullName: "org/example_repository",
 * });
 * ```
 */
export declare function getCodespacesSecrets(args?: GetCodespacesSecretsArgs, opts?: pulumi.InvokeOptions): Promise<GetCodespacesSecretsResult>;
/**
 * A collection of arguments for invoking getCodespacesSecrets.
 */
export interface GetCodespacesSecretsArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: string;
    /**
     * The name of the repository.
     */
    name?: string;
}
/**
 * A collection of values returned by getCodespacesSecrets.
 */
export interface GetCodespacesSecretsResult {
    readonly fullName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Secret name
     */
    readonly name: string;
    /**
     * list of codespaces secrets for the repository
     */
    readonly secrets: outputs.GetCodespacesSecretsSecret[];
}
/**
 * Use this data source to retrieve the list of codespaces secrets for a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getCodespacesSecrets({
 *     name: "example_repository",
 * });
 * const example2 = github.getCodespacesSecrets({
 *     fullName: "org/example_repository",
 * });
 * ```
 */
export declare function getCodespacesSecretsOutput(args?: GetCodespacesSecretsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCodespacesSecretsResult>;
/**
 * A collection of arguments for invoking getCodespacesSecrets.
 */
export interface GetCodespacesSecretsOutputArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: pulumi.Input<string>;
    /**
     * The name of the repository.
     */
    name?: pulumi.Input<string>;
}
