import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about a GitHub Dependabot Organization public key. This data source is required to be used with other GitHub secrets interactions.
 * Note that the provider `token` must have admin rights to an organization to retrieve it's Dependabot public key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getDependabotOrganizationPublicKey({});
 * ```
 */
export declare function getDependabotOrganizationPublicKey(opts?: pulumi.InvokeOptions): Promise<GetDependabotOrganizationPublicKeyResult>;
/**
 * A collection of values returned by getDependabotOrganizationPublicKey.
 */
export interface GetDependabotOrganizationPublicKeyResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Actual key retrieved.
     */
    readonly key: string;
    /**
     * ID of the key that has been retrieved.
     */
    readonly keyId: string;
}
/**
 * Use this data source to retrieve information about a GitHub Dependabot Organization public key. This data source is required to be used with other GitHub secrets interactions.
 * Note that the provider `token` must have admin rights to an organization to retrieve it's Dependabot public key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getDependabotOrganizationPublicKey({});
 * ```
 */
export declare function getDependabotOrganizationPublicKeyOutput(opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDependabotOrganizationPublicKeyResult>;
