import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve the list of dependabot secrets for a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getDependabotSecrets({
 *     name: "example",
 * });
 * ```
 */
export declare function getDependabotSecrets(args?: GetDependabotSecretsArgs, opts?: pulumi.InvokeOptions): Promise<GetDependabotSecretsResult>;
/**
 * A collection of arguments for invoking getDependabotSecrets.
 */
export interface GetDependabotSecretsArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: string;
    /**
     * The name of the repository.
     */
    name?: string;
}
/**
 * A collection of values returned by getDependabotSecrets.
 */
export interface GetDependabotSecretsResult {
    readonly fullName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Secret name
     */
    readonly name: string;
    /**
     * list of dependabot secrets for the repository
     */
    readonly secrets: outputs.GetDependabotSecretsSecret[];
}
/**
 * Use this data source to retrieve the list of dependabot secrets for a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getDependabotSecrets({
 *     name: "example",
 * });
 * ```
 */
export declare function getDependabotSecretsOutput(args?: GetDependabotSecretsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDependabotSecretsResult>;
/**
 * A collection of arguments for invoking getDependabotSecrets.
 */
export interface GetDependabotSecretsOutputArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: pulumi.Input<string>;
    /**
     * The name of the repository.
     */
    name?: pulumi.Input<string>;
}
