import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve information about the IP allow list of an organization.
 * The allow list for IP addresses will block access to private resources via the web, API,
 * and Git from any IP addresses that are not on the allow list.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const all = github.getOrganizationIpAllowList({});
 * ```
 */
export declare function getOrganizationIpAllowList(opts?: pulumi.InvokeOptions): Promise<GetOrganizationIpAllowListResult>;
/**
 * A collection of values returned by getOrganizationIpAllowList.
 */
export interface GetOrganizationIpAllowListResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * An Array of allowed IP addresses.
     * ___
     */
    readonly ipAllowLists: outputs.GetOrganizationIpAllowListIpAllowList[];
}
/**
 * Use this data source to retrieve information about the IP allow list of an organization.
 * The allow list for IP addresses will block access to private resources via the web, API,
 * and Git from any IP addresses that are not on the allow list.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const all = github.getOrganizationIpAllowList({});
 * ```
 */
export declare function getOrganizationIpAllowListOutput(opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetOrganizationIpAllowListResult>;
