import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve the identity provider (IdP) groups for an organization.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const test = github.getOrganizationTeamSyncGroups({});
 * ```
 */
export declare function getOrganizationTeamSyncGroups(opts?: pulumi.InvokeOptions): Promise<GetOrganizationTeamSyncGroupsResult>;
/**
 * A collection of values returned by getOrganizationTeamSyncGroups.
 */
export interface GetOrganizationTeamSyncGroupsResult {
    /**
     * An Array of GitHub Identity Provider Groups.  Each `group` block consists of the fields documented below.
     */
    readonly groups: outputs.GetOrganizationTeamSyncGroupsGroup[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
}
/**
 * Use this data source to retrieve the identity provider (IdP) groups for an organization.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const test = github.getOrganizationTeamSyncGroups({});
 * ```
 */
export declare function getOrganizationTeamSyncGroupsOutput(opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetOrganizationTeamSyncGroupsResult>;
