import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve autolink references for a repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryAutolinkReferences({
 *     repository: "example-repository",
 * });
 * ```
 */
export declare function getRepositoryAutolinkReferences(args: GetRepositoryAutolinkReferencesArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryAutolinkReferencesResult>;
/**
 * A collection of arguments for invoking getRepositoryAutolinkReferences.
 */
export interface GetRepositoryAutolinkReferencesArgs {
    /**
     * Name of the repository to retrieve the autolink references from.
     */
    repository: string;
}
/**
 * A collection of values returned by getRepositoryAutolinkReferences.
 */
export interface GetRepositoryAutolinkReferencesResult {
    /**
     * The list of this repository's autolink references. Each element of `autolinkReferences` has the following attributes:
     */
    readonly autolinkReferences: outputs.GetRepositoryAutolinkReferencesAutolinkReference[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly repository: string;
}
/**
 * Use this data source to retrieve autolink references for a repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryAutolinkReferences({
 *     repository: "example-repository",
 * });
 * ```
 */
export declare function getRepositoryAutolinkReferencesOutput(args: GetRepositoryAutolinkReferencesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryAutolinkReferencesResult>;
/**
 * A collection of arguments for invoking getRepositoryAutolinkReferences.
 */
export interface GetRepositoryAutolinkReferencesOutputArgs {
    /**
     * Name of the repository to retrieve the autolink references from.
     */
    repository: pulumi.Input<string>;
}
