import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve all custom properties of a repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryCustomProperties({
 *     repository: "example-repository",
 * });
 * ```
 */
export declare function getRepositoryCustomProperties(args: GetRepositoryCustomPropertiesArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryCustomPropertiesResult>;
/**
 * A collection of arguments for invoking getRepositoryCustomProperties.
 */
export interface GetRepositoryCustomPropertiesArgs {
    /**
     * Name of the repository to retrieve the custom properties from.
     */
    repository: string;
}
/**
 * A collection of values returned by getRepositoryCustomProperties.
 */
export interface GetRepositoryCustomPropertiesResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The list of this repository's custom properties. Each element of `property` has the following attributes:
     */
    readonly properties: outputs.GetRepositoryCustomPropertiesProperty[];
    readonly repository: string;
}
/**
 * Use this data source to retrieve all custom properties of a repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryCustomProperties({
 *     repository: "example-repository",
 * });
 * ```
 */
export declare function getRepositoryCustomPropertiesOutput(args: GetRepositoryCustomPropertiesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryCustomPropertiesResult>;
/**
 * A collection of arguments for invoking getRepositoryCustomProperties.
 */
export interface GetRepositoryCustomPropertiesOutputArgs {
    /**
     * Name of the repository to retrieve the custom properties from.
     */
    repository: pulumi.Input<string>;
}
