import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve all deploy keys of a repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryDeployKeys({
 *     repository: "example-repository",
 * });
 * ```
 */
export declare function getRepositoryDeployKeys(args: GetRepositoryDeployKeysArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryDeployKeysResult>;
/**
 * A collection of arguments for invoking getRepositoryDeployKeys.
 */
export interface GetRepositoryDeployKeysArgs {
    /**
     * Name of the repository to retrieve the branches from.
     */
    repository: string;
}
/**
 * A collection of values returned by getRepositoryDeployKeys.
 */
export interface GetRepositoryDeployKeysResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The list of this repository's deploy keys. Each element of `keys` has the following attributes:
     */
    readonly keys: outputs.GetRepositoryDeployKeysKey[];
    readonly repository: string;
}
/**
 * Use this data source to retrieve all deploy keys of a repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryDeployKeys({
 *     repository: "example-repository",
 * });
 * ```
 */
export declare function getRepositoryDeployKeysOutput(args: GetRepositoryDeployKeysOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryDeployKeysResult>;
/**
 * A collection of arguments for invoking getRepositoryDeployKeys.
 */
export interface GetRepositoryDeployKeysOutputArgs {
    /**
     * Name of the repository to retrieve the branches from.
     */
    repository: pulumi.Input<string>;
}
