import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve deployment branch policies for a repository / environment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryDeploymentBranchPolicies({
 *     repository: "example-repository",
 *     environmentName: "env_name",
 * });
 * ```
 */
export declare function getRepositoryDeploymentBranchPolicies(args: GetRepositoryDeploymentBranchPoliciesArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryDeploymentBranchPoliciesResult>;
/**
 * A collection of arguments for invoking getRepositoryDeploymentBranchPolicies.
 */
export interface GetRepositoryDeploymentBranchPoliciesArgs {
    /**
     * Name of the environment to retrieve the deployment branch policies  from.
     */
    environmentName: string;
    /**
     * Name of the repository to retrieve the deployment branch policies from.
     */
    repository: string;
}
/**
 * A collection of values returned by getRepositoryDeploymentBranchPolicies.
 */
export interface GetRepositoryDeploymentBranchPoliciesResult {
    /**
     * The list of this repository / environment deployment policies. Each element of `deploymentBranchPolicies` has the following attributes:
     */
    readonly deploymentBranchPolicies: outputs.GetRepositoryDeploymentBranchPoliciesDeploymentBranchPolicy[];
    readonly environmentName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly repository: string;
}
/**
 * Use this data source to retrieve deployment branch policies for a repository / environment.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryDeploymentBranchPolicies({
 *     repository: "example-repository",
 *     environmentName: "env_name",
 * });
 * ```
 */
export declare function getRepositoryDeploymentBranchPoliciesOutput(args: GetRepositoryDeploymentBranchPoliciesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryDeploymentBranchPoliciesResult>;
/**
 * A collection of arguments for invoking getRepositoryDeploymentBranchPolicies.
 */
export interface GetRepositoryDeploymentBranchPoliciesOutputArgs {
    /**
     * Name of the environment to retrieve the deployment branch policies  from.
     */
    environmentName: pulumi.Input<string>;
    /**
     * Name of the repository to retrieve the deployment branch policies from.
     */
    repository: pulumi.Input<string>;
}
