import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve the list of teams which have access to a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryTeams({
 *     name: "example",
 * });
 * ```
 */
export declare function getRepositoryTeams(args?: GetRepositoryTeamsArgs, opts?: pulumi.InvokeOptions): Promise<GetRepositoryTeamsResult>;
/**
 * A collection of arguments for invoking getRepositoryTeams.
 */
export interface GetRepositoryTeamsArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: string;
    /**
     * The name of the repository.
     */
    name?: string;
}
/**
 * A collection of values returned by getRepositoryTeams.
 */
export interface GetRepositoryTeamsResult {
    readonly fullName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Team name
     */
    readonly name: string;
    /**
     * List of teams which have access to the repository
     */
    readonly teams: outputs.GetRepositoryTeamsTeam[];
}
/**
 * Use this data source to retrieve the list of teams which have access to a GitHub repository.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRepositoryTeams({
 *     name: "example",
 * });
 * ```
 */
export declare function getRepositoryTeamsOutput(args?: GetRepositoryTeamsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRepositoryTeamsResult>;
/**
 * A collection of arguments for invoking getRepositoryTeams.
 */
export interface GetRepositoryTeamsOutputArgs {
    /**
     * Full name of the repository (in `org/name` format).
     */
    fullName?: pulumi.Input<string>;
    /**
     * The name of the repository.
     */
    name?: pulumi.Input<string>;
}
