import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about a GitHub resource through REST API.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRestApi({
 *     endpoint: "repos/example_repo/git/refs/heads/main",
 * });
 * ```
 */
export declare function getRestApi(args: GetRestApiArgs, opts?: pulumi.InvokeOptions): Promise<GetRestApiResult>;
/**
 * A collection of arguments for invoking getRestApi.
 */
export interface GetRestApiArgs {
    /**
     * REST API endpoint to send the GET request to.
     */
    endpoint: string;
}
/**
 * A collection of values returned by getRestApi.
 */
export interface GetRestApiResult {
    /**
     * A JSON string containing response body.
     */
    readonly body: string;
    /**
     * A response status code.
     */
    readonly code: number;
    readonly endpoint: string;
    /**
     * A JSON string containing response headers.
     */
    readonly headers: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A response status string.
     */
    readonly status: string;
}
/**
 * Use this data source to retrieve information about a GitHub resource through REST API.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = github.getRestApi({
 *     endpoint: "repos/example_repo/git/refs/heads/main",
 * });
 * ```
 */
export declare function getRestApiOutput(args: GetRestApiOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRestApiResult>;
/**
 * A collection of arguments for invoking getRestApi.
 */
export interface GetRestApiOutputArgs {
    /**
     * REST API endpoint to send the GET request to.
     */
    endpoint: pulumi.Input<string>;
}
