import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about a GitHub user.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * // Retrieve information about a GitHub user.
 * const example = github.getUser({
 *     username: "example",
 * });
 * // Retrieve information about the currently authenticated user.
 * const current = github.getUser({
 *     username: "",
 * });
 * export const currentGithubLogin = current.then(current => current.login);
 * ```
 */
export declare function getUser(args: GetUserArgs, opts?: pulumi.InvokeOptions): Promise<GetUserResult>;
/**
 * A collection of arguments for invoking getUser.
 */
export interface GetUserArgs {
    /**
     * The username. Use an empty string `""` to retrieve information about the currently authenticated user.
     */
    username: string;
}
/**
 * A collection of values returned by getUser.
 */
export interface GetUserResult {
    /**
     * the user's avatar URL.
     */
    readonly avatarUrl: string;
    /**
     * the user's bio.
     */
    readonly bio: string;
    /**
     * the user's blog location.
     */
    readonly blog: string;
    /**
     * the user's company name.
     */
    readonly company: string;
    /**
     * the creation date.
     */
    readonly createdAt: string;
    /**
     * the user's email.
     */
    readonly email: string;
    /**
     * the number of followers.
     */
    readonly followers: number;
    /**
     * the number of following users.
     */
    readonly following: number;
    /**
     * list of user's GPG keys.
     */
    readonly gpgKeys: string[];
    /**
     * the user's gravatar ID.
     */
    readonly gravatarId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * the user's location.
     */
    readonly location: string;
    /**
     * the user's login.
     */
    readonly login: string;
    /**
     * the user's full name.
     */
    readonly name: string;
    /**
     * the Node ID of the user.
     */
    readonly nodeId: string;
    /**
     * the number of public gists.
     */
    readonly publicGists: number;
    /**
     * the number of public repositories.
     */
    readonly publicRepos: number;
    /**
     * whether the user is a GitHub admin.
     */
    readonly siteAdmin: boolean;
    /**
     * list of user's SSH keys.
     */
    readonly sshKeys: string[];
    /**
     * the suspended date if the user is suspended.
     */
    readonly suspendedAt: string;
    /**
     * the update date.
     */
    readonly updatedAt: string;
    readonly username: string;
}
/**
 * Use this data source to retrieve information about a GitHub user.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * // Retrieve information about a GitHub user.
 * const example = github.getUser({
 *     username: "example",
 * });
 * // Retrieve information about the currently authenticated user.
 * const current = github.getUser({
 *     username: "",
 * });
 * export const currentGithubLogin = current.then(current => current.login);
 * ```
 */
export declare function getUserOutput(args: GetUserOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserResult>;
/**
 * A collection of arguments for invoking getUser.
 */
export interface GetUserOutputArgs {
    /**
     * The username. Use an empty string `""` to retrieve information about the currently authenticated user.
     */
    username: pulumi.Input<string>;
}
