import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a GitHub membership resource.
 *
 * This resource allows you to add/remove users from your organization. When applied,
 * an invitation will be sent to the user to become part of the organization. When
 * destroyed, either the invitation will be cancelled or the user will be removed.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * // Add a user to the organization
 * const membershipForSomeUser = new github.Membership("membership_for_some_user", {
 *     username: "SomeUser",
 *     role: "member",
 * });
 * ```
 *
 * ## Import
 *
 * GitHub Membership can be imported using an ID made up of `organization:username`, e.g.
 *
 * ```sh
 * $ pulumi import github:index/membership:Membership member hashicorp:someuser
 * ```
 */
export declare class Membership extends pulumi.CustomResource {
    /**
     * Get an existing Membership resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MembershipState, opts?: pulumi.CustomResourceOptions): Membership;
    /**
     * Returns true if the given object is an instance of Membership.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Membership;
    /**
     * Defaults to `false`. If set to true,
     * when this resource is destroyed, the member will not be removed
     * from the organization. Instead, the member's role will be
     * downgraded to 'member'.
     */
    readonly downgradeOnDestroy: pulumi.Output<boolean | undefined>;
    readonly etag: pulumi.Output<string>;
    /**
     * The role of the user within the organization.
     * Must be one of `member` or `admin`. Defaults to `member`.
     * `admin` role represents the `owner` role available via GitHub UI.
     */
    readonly role: pulumi.Output<string | undefined>;
    /**
     * The user to add to the organization.
     */
    readonly username: pulumi.Output<string>;
    /**
     * Create a Membership resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MembershipArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Membership resources.
 */
export interface MembershipState {
    /**
     * Defaults to `false`. If set to true,
     * when this resource is destroyed, the member will not be removed
     * from the organization. Instead, the member's role will be
     * downgraded to 'member'.
     */
    downgradeOnDestroy?: pulumi.Input<boolean>;
    etag?: pulumi.Input<string>;
    /**
     * The role of the user within the organization.
     * Must be one of `member` or `admin`. Defaults to `member`.
     * `admin` role represents the `owner` role available via GitHub UI.
     */
    role?: pulumi.Input<string>;
    /**
     * The user to add to the organization.
     */
    username?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Membership resource.
 */
export interface MembershipArgs {
    /**
     * Defaults to `false`. If set to true,
     * when this resource is destroyed, the member will not be removed
     * from the organization. Instead, the member's role will be
     * downgraded to 'member'.
     */
    downgradeOnDestroy?: pulumi.Input<boolean>;
    /**
     * The role of the user within the organization.
     * Must be one of `member` or `admin`. Defaults to `member`.
     * `admin` role represents the `owner` role available via GitHub UI.
     */
    role?: pulumi.Input<string>;
    /**
     * The user to add to the organization.
     */
    username: pulumi.Input<string>;
}
