import * as pulumi from "@pulumi/pulumi";
/**
 * This resource allows you to create and manage blocks for GitHub organizations.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = new github.OrganizationBlock("example", {username: "paultyng"});
 * ```
 *
 * ## Import
 *
 * GitHub organization block can be imported using a username, e.g.
 *
 * ```sh
 * $ pulumi import github:index/organizationBlock:OrganizationBlock example someuser
 * ```
 */
export declare class OrganizationBlock extends pulumi.CustomResource {
    /**
     * Get an existing OrganizationBlock resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: OrganizationBlockState, opts?: pulumi.CustomResourceOptions): OrganizationBlock;
    /**
     * Returns true if the given object is an instance of OrganizationBlock.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OrganizationBlock;
    readonly etag: pulumi.Output<string>;
    /**
     * The name of the user to block.
     */
    readonly username: pulumi.Output<string>;
    /**
     * Create a OrganizationBlock resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OrganizationBlockArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering OrganizationBlock resources.
 */
export interface OrganizationBlockState {
    etag?: pulumi.Input<string>;
    /**
     * The name of the user to block.
     */
    username?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a OrganizationBlock resource.
 */
export interface OrganizationBlockArgs {
    /**
     * The name of the user to block.
     */
    username: pulumi.Input<string>;
}
