import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const someTeam = new github.Team("some_team", {
 *     name: "SomeTeam",
 *     description: "Some cool team",
 * });
 * const someTeamOrganizationSecurityManager = new github.OrganizationSecurityManager("some_team", {teamSlug: someTeam.slug});
 * ```
 *
 * ## Import
 *
 * GitHub Security Manager Teams can be imported using the GitHub team ID e.g.
 *
 * ```sh
 * $ pulumi import github:index/organizationSecurityManager:OrganizationSecurityManager core 1234567
 * ```
 */
export declare class OrganizationSecurityManager extends pulumi.CustomResource {
    /**
     * Get an existing OrganizationSecurityManager resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: OrganizationSecurityManagerState, opts?: pulumi.CustomResourceOptions): OrganizationSecurityManager;
    /**
     * Returns true if the given object is an instance of OrganizationSecurityManager.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OrganizationSecurityManager;
    /**
     * The slug of the team to manage.
     */
    readonly teamSlug: pulumi.Output<string>;
    /**
     * Create a OrganizationSecurityManager resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OrganizationSecurityManagerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering OrganizationSecurityManager resources.
 */
export interface OrganizationSecurityManagerState {
    /**
     * The slug of the team to manage.
     */
    teamSlug?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a OrganizationSecurityManager resource.
 */
export interface OrganizationSecurityManagerArgs {
    /**
     * The slug of the team to manage.
     */
    teamSlug: pulumi.Input<string>;
}
