import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * This resource allows you to create and manage Identity Provider (IdP) group connections within your GitHub teams.
 * You must have team synchronization enabled for organizations owned by enterprise accounts.
 *
 * To learn more about team synchronization between IdPs and GitHub, please refer to:
 * https://help.github.com/en/github/setting-up-and-managing-organizations-and-teams/synchronizing-teams-between-your-identity-provider-and-github
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const exampleGroups = github.getOrganizationTeamSyncGroups({});
 * const exampleGroupMapping = new github.TeamSyncGroupMapping("example_group_mapping", {
 *     groups: .map(entry => ({
 *         groupId: entry.value.groupId,
 *         groupName: entry.value.groupName,
 *         groupDescription: entry.value.groupDescription,
 *     })),
 *     teamSlug: "example",
 * });
 * ```
 *
 * ## Import
 *
 * GitHub Team Sync Group Mappings can be imported using the GitHub team `slug` e.g.
 *
 * ```sh
 * $ pulumi import github:index/teamSyncGroupMapping:TeamSyncGroupMapping example some_team
 * ```
 */
export declare class TeamSyncGroupMapping extends pulumi.CustomResource {
    /**
     * Get an existing TeamSyncGroupMapping resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TeamSyncGroupMappingState, opts?: pulumi.CustomResourceOptions): TeamSyncGroupMapping;
    /**
     * Returns true if the given object is an instance of TeamSyncGroupMapping.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TeamSyncGroupMapping;
    readonly etag: pulumi.Output<string>;
    /**
     * An Array of GitHub Identity Provider Groups (or empty []).  Each `group` block consists of the fields documented below.
     * ___
     *
     * The `group` block consists of:
     */
    readonly groups: pulumi.Output<outputs.TeamSyncGroupMappingGroup[] | undefined>;
    /**
     * Slug of the team
     */
    readonly teamSlug: pulumi.Output<string>;
    /**
     * Create a TeamSyncGroupMapping resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TeamSyncGroupMappingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering TeamSyncGroupMapping resources.
 */
export interface TeamSyncGroupMappingState {
    etag?: pulumi.Input<string>;
    /**
     * An Array of GitHub Identity Provider Groups (or empty []).  Each `group` block consists of the fields documented below.
     * ___
     *
     * The `group` block consists of:
     */
    groups?: pulumi.Input<pulumi.Input<inputs.TeamSyncGroupMappingGroup>[]>;
    /**
     * Slug of the team
     */
    teamSlug?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a TeamSyncGroupMapping resource.
 */
export interface TeamSyncGroupMappingArgs {
    /**
     * An Array of GitHub Identity Provider Groups (or empty []).  Each `group` block consists of the fields documented below.
     * ___
     *
     * The `group` block consists of:
     */
    groups?: pulumi.Input<pulumi.Input<inputs.TeamSyncGroupMappingGroup>[]>;
    /**
     * Slug of the team
     */
    teamSlug: pulumi.Input<string>;
}
